# Representational Similarity Measures (RSM)

This repository centralizes various measures of similarity for representations, specifically tailored for comparing the weights and outputs of deep learning models. It provides tools and methods to assess and analyze similarities between different models and layers, aiding in model evaluation and research.

This repository is based on the compilation of similarity metrics presented in the survey [Klabunde, 2023](https://arxiv.org/abs/2305.06329). The study exposes various types of metrics; for the coding, the logics presented in the study have been followed, and PyTorch has been used for the implementation.

Currently, the project status can be seen in the following [table](table.md). In it, you will find the different features that have been programmed and how to call each of the functions that define them.

## How to install

To install the library you can use the next command:

```python
pip install deep-reps==0.0.1
```
